@@ -47,7 +47,7 @@ CommitImpl::CommitImpl(Git* g, bool amend) : git(g) {
 
 		bool inIndex = f->statusCmp(i, RevFile::IN_INDEX);
 		bool isNew = (f->statusCmp(i, RevFile::NEW) || f->statusCmp(i, RevFile::UNKNOWN));
-		QColor myColor = Qt::black;
+		QColor myColor = QPalette().color(QPalette::WindowText);
 		if (isNew)
 			myColor = Qt::darkGreen;
 		else if (f->statusCmp(i, RevFile::DELETED))
@@ -234,8 +234,8 @@ bool CommitImpl::checkPatchName(QString& patchName) {
 
 bool CommitImpl::checkConfirm(SCRef msg, SCRef patchName, SCList selFiles, bool amend) {
 
-	QTextCodec* tc = QTextCodec::codecForCStrings();
-	QTextCodec::setCodecForCStrings(0); // set temporary Latin-1
+//	QTextCodec* tc = QTextCodec::codecForCStrings();
+//	QTextCodec::setCodecForCStrings(0); // set temporary Latin-1
 
 	// NOTEME: i18n-ugly
 	QString whatToDo = amend ?
@@ -257,7 +257,7 @@ bool CommitImpl::checkConfirm(SCRef msg, SCRef patchName, SCList selFiles, bool
 	if (git->isStGITStack())
 		text.append("\n\nAnd patch name: " + patchName);
 
-	QTextCodec::setCodecForCStrings(tc);
+//	QTextCodec::setCodecForCStrings(tc);
 
         QMessageBox msgBox(this);
         msgBox.setWindowTitle("Commit changes - QGit");
