@@ -12,6 +12,7 @@
 #include <QFont>
 #include <QHash>
 #include <QLatin1String>
+#include <QSet>
 #include <QVariant>
 #include <QVector>
 
@@ -346,7 +347,7 @@ class RevFile {
 	// Status information is splitted in a flags vector and in a string
 	// vector in 'status' are stored flags according to the info returned
 	// by 'git diff-tree' without -C option.
-	// In case of a working dir file an IN_INDEX flag is or-ed togheter in
+        // In case of a working directory file an IN_INDEX flag is or-ed togheter in
 	// case file is present in git index.
 	// If file is renamed or copied an entry in 'extStatus' stores the
 	// value returned by 'git diff-tree -C' plus source and destination
@@ -453,3 +454,5 @@ private:
 };
 
 #endif
+
+QString qt4and5escaping(QString toescape);
