@@ -8,10 +8,12 @@
 */
 #include <QApplication>
 #include <QHeaderView>
+#include <QMimeData>
 #include <QMouseEvent>
 #include <QPainter>
 #include <QPixmap>
 #include <QShortcut>
+#include "FileHistory.h"
 #include "domain.h"
 #include "git.h"
 #include "listview.h"
@@ -86,9 +88,9 @@ void ListView::setupGeometry() {
 
 	QHeaderView* hv = header();
 	hv->setStretchLastSection(true);
-	hv->setResizeMode(LOG_COL, QHeaderView::Interactive);
-	hv->setResizeMode(TIME_COL, QHeaderView::Interactive);
-	hv->setResizeMode(ANN_ID_COL, QHeaderView::ResizeToContents);
+	hv->setSectionResizeMode(LOG_COL, QHeaderView::Interactive);
+	hv->setSectionResizeMode(TIME_COL, QHeaderView::Interactive);
+	hv->setSectionResizeMode(ANN_ID_COL, QHeaderView::ResizeToContents);
 	hv->resizeSection(GRAPH_COL, DEF_GRAPH_COL_WIDTH);
 	hv->resizeSection(LOG_COL, DEF_LOG_COL_WIDTH);
 	hv->resizeSection(AUTH_COL, DEF_AUTH_COL_WIDTH);
@@ -457,7 +459,8 @@ void ListViewDelegate::paintGraphLane(QPainter* p, int type, int x1, int x2,
 	#define CENTER_DL x2, 0  ,  45
 	#define R_CENTER m - r, h - r, d, d
 
-        static QPen lanePen(Qt::black, 2); // fast path here
+	static QColor const & lanePenColor = QPalette().color(QPalette::WindowText);
+	static QPen lanePen(lanePenColor, 2); // fast path here
 
 	// arc
 	switch (type) {
@@ -618,8 +621,8 @@ void ListViewDelegate::paintGraphLane(QPainter* p, int type, int x1, int x2,
 
 void ListViewDelegate::paintGraph(QPainter* p, const QStyleOptionViewItem& opt,
                                   const QModelIndex& i) const {
-
-	static const QColor colors[COLORS_NUM] = { Qt::red, DARK_GREEN,
+	static const QColor & baseColor = QPalette().color(QPalette::WindowText);
+	static const QColor colors[COLORS_NUM] = { baseColor, Qt::red, DARK_GREEN,
 	                                           Qt::blue, Qt::darkGray, BROWN,
 	                                           Qt::magenta, ORANGE };
 	if (opt.state & QStyle::State_Selected)
@@ -776,6 +779,7 @@ void ListViewDelegate::addRefPixmap(QPixmap** pp, SCRef sha, int type, QStyleOpt
 			clr = PURPLE;
 
 		opt.palette.setColor(QPalette::Window, clr);
+		opt.palette.setColor(QPalette::WindowText, QColor(Qt::black));
 		addTextPixmap(pp, *it, opt);
 	}
 }
