@@ -13,6 +13,7 @@
 #include <QInputDialog>
 #include <QMenu>
 #include <QMessageBox>
+#include <QMimeData>
 #include <QProgressBar>
 #include <QScrollBar>
 #include <QSettings>
@@ -325,7 +326,7 @@ void MainImpl::setRepository(SCRef newDir, bool refresh, bool keepSelection,
 	   On returning from processEvents() an exception is trown and init is exited,
 	   so we end up with a long list of 'exception thrown' messages.
 	   But the worst thing is that we have to wait for _all_ the init call to exit
-	   and this could take a long time as example in case of working dir refreshing
+           and this could take a long time as example in case of working directory refreshing
 	   'git update-index' of a big tree.
 	   So we use a guard flag to guarantee we have only one init() call 'in flight'
 	*/
@@ -344,7 +345,7 @@ void MainImpl::setRepository(SCRef newDir, bool refresh, bool keepSelection,
 		EM_REGISTER(exExiting);
 
 		bool archiveChanged;
-		curDir = git->getBaseDir(&archiveChanged, newDir);
+                git->getBaseDir(newDir, curDir, archiveChanged);
 
 		git->stop(archiveChanged); // stop all pending processes, non blocking
 
@@ -942,64 +943,55 @@ void MainImpl::setupShortcuts() {
 void MainImpl::shortCutActivated() {
 
 	QShortcut* se = dynamic_cast<QShortcut*>(sender());
-	if (!se)
-		return;
 
-	bool isKey_P = false;
+	if (se) {
+		const QKeySequence& key = se->key();
 
-	switch (se->key()) {
-
-	case Qt::Key_I:
-		rv->tab()->listViewLog->on_keyUp();
-		break;
-	case Qt::Key_K:
-	case Qt::Key_N:
-		rv->tab()->listViewLog->on_keyDown();
-		break;
-	case Qt::SHIFT | Qt::Key_Up:
-		goMatch(-1);
-		break;
-	case Qt::SHIFT | Qt::Key_Down:
-		goMatch(1);
-		break;
-	case Qt::Key_Left:
-		ActBack_activated();
-		break;
-	case Qt::Key_Right:
-		ActForward_activated();
-		break;
-	case Qt::CTRL | Qt::Key_Plus:
-		adjustFontSize(1);
-		break;
-	case Qt::CTRL | Qt::Key_Minus:
-		adjustFontSize(-1);
-		break;
-	case Qt::Key_U:
-		scrollTextEdit(-18);
-		break;
-	case Qt::Key_D:
-		scrollTextEdit(18);
-		break;
-	case Qt::Key_Delete:
-	case Qt::Key_B:
-	case Qt::Key_Backspace:
-		scrollTextEdit(-1);
-		break;
-	case Qt::Key_Space:
-		scrollTextEdit(1);
-		break;
-	case Qt::Key_R:
-		tabWdg->setCurrentWidget(rv->tabPage());
-		break;
-	case Qt::Key_P:
-		isKey_P = true;
-	case Qt::Key_F: {
-		QWidget* cp = tabWdg->currentWidget();
-		Domain* d = isKey_P ? static_cast<Domain*>(firstTab<PatchView>(cp)) :
-		                      static_cast<Domain*>(firstTab<FileView>(cp));
-		if (d)
-			tabWdg->setCurrentWidget(d->tabPage()); }
-		break;
+		if (key == Qt::Key_I) {
+			rv->tab()->listViewLog->on_keyUp();
+		}
+		else if (key == Qt::Key_K or key == Qt::Key_N) {
+			rv->tab()->listViewLog->on_keyDown();
+		}
+		else if (key == Qt::SHIFT | Qt::Key_Up) {
+			goMatch(-1);
+		}
+		else if (key == Qt::SHIFT | Qt::Key_Down) {
+			goMatch(1);
+		}
+		else if (key == Qt::Key_Left) {
+			ActBack_activated();
+		}
+		else if (key == Qt::Key_Right) {
+			ActForward_activated();
+		}
+		else if (key == Qt::CTRL | Qt::Key_Plus) {
+			adjustFontSize(1); //TODO replace magic constant
+		}
+		else if (key == Qt::CTRL | Qt::Key_Minus) {
+			adjustFontSize(-1); //TODO replace magic constant
+		}
+		else if (key == Qt::Key_U) {
+			scrollTextEdit(-18); //TODO replace magic constant
+		}
+		else if (key == Qt::Key_D) {
+			scrollTextEdit(18); //TODO replace magic constant
+		}
+		else if (key == Qt::Key_Delete or key == Qt::Key_B or key == Qt::Key_Backspace) {
+			scrollTextEdit(-1); //TODO replace magic constant
+		}
+		else if (key == Qt::Key_Space) {
+			scrollTextEdit(1);
+		}
+		else if (key == Qt::Key_R) {
+			tabWdg->setCurrentWidget(rv->tabPage());
+		}
+		else if (key == Qt::Key_P or key == Qt::Key_F) {
+			QWidget* cp = tabWdg->currentWidget();
+			Domain* d = key == Qt::Key_P? static_cast<Domain*>(firstTab<PatchView>(cp)) :
+						      static_cast<Domain*>(firstTab<FileView>(cp));
+			if (d) tabWdg->setCurrentWidget(d->tabPage());
+		}
 	}
 }
 
@@ -1100,8 +1092,7 @@ void MainImpl::doUpdateRecentRepoMenu(SCRef newEntry) {
 
 	QList<QAction*> al(File->actions());
 	FOREACH (QList<QAction*>, it, al) {
-		SCRef txt = (*it)->text();
-		if (!txt.isEmpty() && txt.at(0).isDigit())
+		if ((*it)->data().toString().startsWith(QStringLiteral("RECENT")))
 			File->removeAction(*it);
 	}
 	QSettings settings;
@@ -1116,7 +1107,8 @@ void MainImpl::doUpdateRecentRepoMenu(SCRef newEntry) {
 	idx = 1;
 	QStringList newRecents;
 	FOREACH_SL (it, recents) {
-		File->addAction(QString::number(idx++) + " " + *it);
+		QAction* newAction = File->addAction(QString::number(idx++) + " " + *it);
+		newAction->setData(QStringLiteral("RECENT ") + *it);
 		newRecents << *it;
 		if (idx > MAX_RECENT_REPOS)
 			break;
@@ -1363,12 +1355,12 @@ void MainImpl::ActSaveFile_activated() {
 
 void MainImpl::openRecent_triggered(QAction* act) {
 
-	bool ok;
-	act->text().left(1).toInt(&ok);
-	if (!ok) // only recent repos entries have a number in first char
+	const QString dataString = act->data().toString();
+	if (!dataString.startsWith(QStringLiteral("RECENT")))
+		// only recent repos entries have "RECENT" in data field
 		return;
 
-	const QString workDir(act->text().section(' ', 1));
+	const QString workDir = dataString.mid(7);
 	if (!workDir.isEmpty()) {
 		QDir d(workDir);
 		if (d.exists())
@@ -1440,7 +1432,7 @@ bool MainImpl::askApplyPatchParameters(bool* workDirOnly, bool* fold) {
 	if (!git->isStGITStack()) {
 		ret = QMessageBox::question(this, "Apply Patch",
 		      "Do you want to commit or just to apply changes to "
-		      "working directory?", "&Cancel", "&Working dir", "&Commit", 0, 0);
+                      "working directory?", "&Cancel", "&Working directory", "&Commit", 0, 0);
 		*workDirOnly = (ret == 1);
 		*fold = false;
 	} else {
@@ -1821,7 +1813,7 @@ void MainImpl::ActAbout_activated() {
 	static const char* aboutMsg =
 	"<p><b>QGit version " PACKAGE_VERSION "</b></p>"
 	"<p>Copyright (c) 2005, 2007, 2008 Marco Costalba</p>"
-    "<p>Use and redistribute under the terms of the<br>"
+	"<p>Use and redistribute under the terms of the<br>"
 	"<a href=\"http://www.gnu.org/licenses/old-licenses/gpl-2.0.html\">GNU General Public License Version 2</a></p>"
 	"<p>Contributors:<br>"
 	"Copyright (c) 2007 Andy Parkins<br>"
@@ -1831,11 +1823,16 @@ void MainImpl::ActAbout_activated() {
 	"Copyright (c) 2007 James McKaskill<br>"
 	"Copyright (c) 2008 Jan Hudec<br>"
 	"Copyright (c) 2008 Paul Gideon Dann<br>"
-    "Copyright (c) 2008 Oliver Bock<br>"
-    "Copyright (c) 2010 Cyp &lt;cyp561@gmail.com&gt;<br>"
-    "Copyright (c) 2011 Jean-Franois Dagenais &lt;dagenaisj@sonatest.com&gt;<br>"
-    "Copyright (c) 2011 Pavel Tikhomirov &lt;pavtih@gmail.com&gt;<br>"
-    "Copyright (c) 2011 Cristian Tibirna &lt;tibirna@kde.org&gt;<br>"
+	"Copyright (c) 2008 Oliver Bock<br>"
+	"Copyright (c) 2010 Cyp &lt;cyp561@gmail.com&gt;<br>"
+	"Copyright (c) 2011 Jean-Fran&ccedil;ois Dagenais &lt;dagenaisj@sonatest.com&gt;<br>"
+	"Copyright (c) 2011 Pavel Tikhomirov &lt;pavtih@gmail.com&gt;<br>"
+	"Copyright (c) 2011-2016 Cristian Tibirna &lt;tibirna@kde.org&gt;<br>"
+	"Copyright (c) 2011 Tim Blechmann &lt;tim@klingt.org&gt;<br>"
+	"Copyright (c) 2014 Gregor Mi &lt;codestruct@posteo.org&gt;<br>"
+	"Copyright (c) 2014 Sbytov N.N &lt;sbytnn@gmail.com&gt;<br>"
+	"Copyright (c) 2015 Daniel Levin &lt;dendy.ua@gmail.com&gt;<br>"
+	"Copyright (c) 2016 Luigi Toscano &lt;luigi.toscano@tiscali.it&gt;"
     "</p>"
 
 	"<p>This version was compiled against Qt " QT_VERSION_STR "</p>";
